pro\_football\_reference\_web\_scraper package
==============================================

Submodules
----------

pro\_football\_reference\_web\_scraper.player\_game\_log module
---------------------------------------------------------------

.. automodule:: pro_football_reference_web_scraper.player_game_log
.. autofunction:: player_game_log.get_player_game_log

pro\_football\_reference\_web\_scraper.team\_game\_log module
-------------------------------------------------------------

.. automodule:: pro_football_reference_web_scraper.team_game_log
.. autofunction:: team_game_log.get_team_game_log

pro\_football\_reference\_web\_scraper.player\_splits module
-------------------------------------------------------------

.. automodule:: pro_football_reference_web_scraper.player_splits
.. autofunction:: player_splits.home_road
.. autofunction:: player_splits.win_loss

pro\_football\_reference\_web\_scraper.team\_splits module
-------------------------------------------------------------

.. automodule:: pro_football_reference_web_scraper.team_splits
.. autofunction:: team_splits.home_road
.. autofunction:: team_splits.win_loss


Module contents
---------------

.. automodule:: pro_football_reference_web_scraper
   :members:
   :undoc-members:
   :show-inheritance:
